@@ -6,6 +6,8 @@ class Authenticate:
         self.asset = asset
         self.asset_meta = asset_schema.get('meta', {})
         self.params = {}
+        self.auth_error = False
+        self.auth_error_response = None
 
         self.session = WrappedSession()
         self.session.proxies = {
@@ -72,11 +74,15 @@ class Authenticate:
         }
 
         token_url = self.asset.get("token_url") or urljoin(self.url, self.asset_meta['token_endpoint'])
-        access_token = self.session.request("POST",
-                                            token_url,
-                                            data=data).json()['access_token']
-
-        self.session.headers.update({"Authorization": "Bearer {}".format(access_token)})
+        response = self.session.request("POST",
+                                        token_url,
+                                        data=data)
+        if response.status_code >= 300:
+            self.auth_error = True
+            self.auth_error_response = response
+        else:
+            access_token = response.json()['access_token']
+            self.session.headers.update({"Authorization": "Bearer {}".format(access_token)})
 
 
 class WrappedSession(Session):
