@@ -8,6 +8,8 @@ from .attachments import parse_attachment_output
 class Runner(Authenticate):
 
     def run(self, inputs, action_schema):
+        if self.auth_error:
+            return self.parse_response(self.auth_error_response, action_schema)
         response = self.session.request(
             method=self.get_method(inputs, action_schema['meta']),
             url=urljoin(self.url, self.get_endpoint(inputs, action_schema['meta'])),
@@ -46,9 +48,11 @@ class Runner(Authenticate):
             'response_headers': dict(response.headers),
             'reason': response.reason
         }
-        file = parse_attachment_output(response, action_schema)
-        if file:
-            output['file'] = file
+        if response.status_code < 300:
+            # Only create an attachment if we have a successful response
+            file = parse_attachment_output(response, action_schema)
+            if file:
+                output['file'] = file
 
         try:
             output['json_body'] = response.json()
